kedro.framework.cli.pipeline.PipelineArtifacts — Kedro 0.17.6 documentation

# kedro.framework.cli.pipeline.PipelineArtifacts

class `kedro.framework.cli.pipeline.` `PipelineArtifacts`(pipeline_dir: pathlib.Path, pipeline_tests: pathlib.Path, pipeline_conf: pathlib.Path)

  An ordered collection of source_path, tests_path, config_paths

  Attributes

  `pipeline_conf` | Alias for field number 2
  `pipeline_dir` | Alias for field number 0
  `pipeline_tests` | Alias for field number 1

  Methods

  `count`(value) |
  `index`(value, [start, [stop]]) | Raises ValueError if the value is not present.

  `count`(value) → integer – return number of occurrences of value
  `index`(value[, start[, stop]]) → integer – return first index of value.

    Raises ValueError if the value is not present.

  property `pipeline_conf`

    Alias for field number 2

  property `pipeline_dir`

    Alias for field number 0

  property `pipeline_tests`

    Alias for field number 1